@@ -39,13 +39,17 @@ OQS_API const char *OQS_KEM_alg_identifier(size_t i) {
 		OQS_KEM_alg_ntru_hps2048509,
 		OQS_KEM_alg_ntru_hps2048677,
 		OQS_KEM_alg_ntru_hps4096821,
+		OQS_KEM_alg_ntru_hps40961229,
 		OQS_KEM_alg_ntru_hrss701,
+		OQS_KEM_alg_ntru_hrss1373,
 		OQS_KEM_alg_ntruprime_ntrulpr653,
 		OQS_KEM_alg_ntruprime_ntrulpr761,
 		OQS_KEM_alg_ntruprime_ntrulpr857,
+		OQS_KEM_alg_ntruprime_ntrulpr1277,
 		OQS_KEM_alg_ntruprime_sntrup653,
 		OQS_KEM_alg_ntruprime_sntrup761,
 		OQS_KEM_alg_ntruprime_sntrup857,
+		OQS_KEM_alg_ntruprime_sntrup1277,
 		OQS_KEM_alg_saber_lightsaber,
 		OQS_KEM_alg_saber_saber,
 		OQS_KEM_alg_saber_firesaber,
@@ -231,12 +235,24 @@ OQS_API int OQS_KEM_alg_is_enabled(const char *method_name) {
 		return 1;
 #else
 		return 0;
+#endif
+	} else if (0 == strcasecmp(method_name, OQS_KEM_alg_ntru_hps40961229)) {
+#ifdef OQS_ENABLE_KEM_ntru_hps40961229
+		return 1;
+#else
+		return 0;
 #endif
 	} else if (0 == strcasecmp(method_name, OQS_KEM_alg_ntru_hrss701)) {
 #ifdef OQS_ENABLE_KEM_ntru_hrss701
 		return 1;
 #else
 		return 0;
+#endif
+	} else if (0 == strcasecmp(method_name, OQS_KEM_alg_ntru_hrss1373)) {
+#ifdef OQS_ENABLE_KEM_ntru_hrss1373
+		return 1;
+#else
+		return 0;
 #endif
 	} else if (0 == strcasecmp(method_name, OQS_KEM_alg_ntruprime_ntrulpr653)) {
 #ifdef OQS_ENABLE_KEM_ntruprime_ntrulpr653
@@ -255,6 +271,12 @@ OQS_API int OQS_KEM_alg_is_enabled(const char *method_name) {
 		return 1;
 #else
 		return 0;
+#endif
+	} else if (0 == strcasecmp(method_name, OQS_KEM_alg_ntruprime_ntrulpr1277)) {
+#ifdef OQS_ENABLE_KEM_ntruprime_ntrulpr1277
+		return 1;
+#else
+		return 0;
 #endif
 	} else if (0 == strcasecmp(method_name, OQS_KEM_alg_ntruprime_sntrup653)) {
 #ifdef OQS_ENABLE_KEM_ntruprime_sntrup653
@@ -273,6 +295,12 @@ OQS_API int OQS_KEM_alg_is_enabled(const char *method_name) {
 		return 1;
 #else
 		return 0;
+#endif
+	} else if (0 == strcasecmp(method_name, OQS_KEM_alg_ntruprime_sntrup1277)) {
+#ifdef OQS_ENABLE_KEM_ntruprime_sntrup1277
+		return 1;
+#else
+		return 0;
 #endif
 	} else if (0 == strcasecmp(method_name, OQS_KEM_alg_saber_lightsaber)) {
 #ifdef OQS_ENABLE_KEM_saber_lightsaber
@@ -579,12 +607,24 @@ OQS_API OQS_KEM *OQS_KEM_new(const char *method_name) {
 		return OQS_KEM_ntru_hps4096821_new();
 #else
 		return NULL;
+#endif
+	} else if (0 == strcasecmp(method_name, OQS_KEM_alg_ntru_hps40961229)) {
+#ifdef OQS_ENABLE_KEM_ntru_hps40961229
+		return OQS_KEM_ntru_hps40961229_new();
+#else
+		return NULL;
 #endif
 	} else if (0 == strcasecmp(method_name, OQS_KEM_alg_ntru_hrss701)) {
 #ifdef OQS_ENABLE_KEM_ntru_hrss701
 		return OQS_KEM_ntru_hrss701_new();
 #else
 		return NULL;
+#endif
+	} else if (0 == strcasecmp(method_name, OQS_KEM_alg_ntru_hrss1373)) {
+#ifdef OQS_ENABLE_KEM_ntru_hrss1373
+		return OQS_KEM_ntru_hrss1373_new();
+#else
+		return NULL;
 #endif
 	} else if (0 == strcasecmp(method_name, OQS_KEM_alg_ntruprime_ntrulpr653)) {
 #ifdef OQS_ENABLE_KEM_ntruprime_ntrulpr653
@@ -603,6 +643,12 @@ OQS_API OQS_KEM *OQS_KEM_new(const char *method_name) {
 		return OQS_KEM_ntruprime_ntrulpr857_new();
 #else
 		return NULL;
+#endif
+	} else if (0 == strcasecmp(method_name, OQS_KEM_alg_ntruprime_ntrulpr1277)) {
+#ifdef OQS_ENABLE_KEM_ntruprime_ntrulpr1277
+		return OQS_KEM_ntruprime_ntrulpr1277_new();
+#else
+		return NULL;
 #endif
 	} else if (0 == strcasecmp(method_name, OQS_KEM_alg_ntruprime_sntrup653)) {
 #ifdef OQS_ENABLE_KEM_ntruprime_sntrup653
@@ -621,6 +667,12 @@ OQS_API OQS_KEM *OQS_KEM_new(const char *method_name) {
 		return OQS_KEM_ntruprime_sntrup857_new();
 #else
 		return NULL;
+#endif
+	} else if (0 == strcasecmp(method_name, OQS_KEM_alg_ntruprime_sntrup1277)) {
+#ifdef OQS_ENABLE_KEM_ntruprime_sntrup1277
+		return OQS_KEM_ntruprime_sntrup1277_new();
+#else
+		return NULL;
 #endif
 	} else if (0 == strcasecmp(method_name, OQS_KEM_alg_saber_lightsaber)) {
 #ifdef OQS_ENABLE_KEM_saber_lightsaber
