@@ -80,20 +80,28 @@ extern "C" {
 #define OQS_KEM_alg_ntru_hps2048677 "NTRU-HPS-2048-677"
 /** Algorithm identifier for NTRU-HPS-4096-821 KEM. */
 #define OQS_KEM_alg_ntru_hps4096821 "NTRU-HPS-4096-821"
+/** Algorithm identifier for NTRU-HPS-4096-1229 KEM. */
+#define OQS_KEM_alg_ntru_hps40961229 "NTRU-HPS-4096-1229"
 /** Algorithm identifier for NTRU-HRSS-701 KEM. */
 #define OQS_KEM_alg_ntru_hrss701 "NTRU-HRSS-701"
+/** Algorithm identifier for NTRU-HRSS-1373 KEM. */
+#define OQS_KEM_alg_ntru_hrss1373 "NTRU-HRSS-1373"
 /** Algorithm identifier for ntrulpr653 KEM. */
 #define OQS_KEM_alg_ntruprime_ntrulpr653 "ntrulpr653"
 /** Algorithm identifier for ntrulpr761 KEM. */
 #define OQS_KEM_alg_ntruprime_ntrulpr761 "ntrulpr761"
 /** Algorithm identifier for ntrulpr857 KEM. */
 #define OQS_KEM_alg_ntruprime_ntrulpr857 "ntrulpr857"
+/** Algorithm identifier for ntrulpr1277 KEM. */
+#define OQS_KEM_alg_ntruprime_ntrulpr1277 "ntrulpr1277"
 /** Algorithm identifier for sntrup653 KEM. */
 #define OQS_KEM_alg_ntruprime_sntrup653 "sntrup653"
 /** Algorithm identifier for sntrup761 KEM. */
 #define OQS_KEM_alg_ntruprime_sntrup761 "sntrup761"
 /** Algorithm identifier for sntrup857 KEM. */
 #define OQS_KEM_alg_ntruprime_sntrup857 "sntrup857"
+/** Algorithm identifier for sntrup1277 KEM. */
+#define OQS_KEM_alg_ntruprime_sntrup1277 "sntrup1277"
 /** Algorithm identifier for LightSaber-KEM KEM. */
 #define OQS_KEM_alg_saber_lightsaber "LightSaber-KEM"
 /** Algorithm identifier for Saber-KEM KEM. */
@@ -148,7 +156,7 @@ extern "C" {
 // EDIT-WHEN-ADDING-KEM
 ///// OQS_COPY_FROM_UPSTREAM_FRAGMENT_ALGS_LENGTH_START
 /** Number of algorithm identifiers above. */
-#define OQS_KEM_algs_length 56
+#define OQS_KEM_algs_length 60
 ///// OQS_COPY_FROM_UPSTREAM_FRAGMENT_ALGS_LENGTH_END
 
 /**
