@@ -36,7 +36,7 @@ static uint32_t numBytes(uint32_t numBits) {
   return (numBits + 7) >> 3;
 }
 
-static void createRandomTapes(randomTape_t* tapes, uint8_t** seeds, uint8_t* salt, size_t t,
+static void createRandomTapes(randomTape_t* tapes, uint8_t* seeds, uint8_t* salt, size_t t,
                               const picnic_instance_t* params) {
   hash_context_x4 ctx;
 
@@ -47,18 +47,17 @@ static void createRandomTapes(randomTape_t* tapes, uint8_t** seeds, uint8_t* sal
   for (size_t i = 0; i < params->num_MPC_parties; i += 4) {
     hash_init_x4(&ctx, params->digest_size);
 
-    const uint8_t* seeds_ptr[4] = {seeds[i], seeds[i + 1], seeds[i + 2], seeds[i + 3]};
-    hash_update_x4(&ctx, seeds_ptr, params->seed_size);
-    const uint8_t* salt_ptr[4] = {salt, salt, salt, salt};
-    hash_update_x4(&ctx, salt_ptr, SALT_SIZE);
+    hash_update_x4_4(&ctx, &seeds[i * params->seed_size], &seeds[(i + 1) * params->seed_size],
+                     &seeds[(i + 2) * params->seed_size], &seeds[(i + 3) * params->seed_size],
+                     params->seed_size);
+    hash_update_x4_1(&ctx, salt, SALT_SIZE);
     hash_update_x4_uint16_le(&ctx, t);
     const uint16_t i_arr[4] = {i + 0, i + 1, i + 2, i + 3};
     hash_update_x4_uint16s_le(&ctx, i_arr);
     hash_final_x4(&ctx);
 
-    uint8_t* out_ptr[4] = {tapes->tape[i], tapes->tape[i + 1], tapes->tape[i + 2],
-                           tapes->tape[i + 3]};
-    hash_squeeze_x4(&ctx, out_ptr, tapeSizeBytes);
+    hash_squeeze_x4_4(&ctx, tapes->tape[i], tapes->tape[i + 1], tapes->tape[i + 2],
+                      tapes->tape[i + 3], tapeSizeBytes);
     hash_clear_x4(&ctx);
   }
 }
@@ -124,8 +123,7 @@ static void commit_x4(uint8_t** digest, const uint8_t** seed, const uint8_t* sal
 
   hash_init_x4(&ctx, params->digest_size);
   hash_update_x4(&ctx, seed, params->seed_size);
-  const uint8_t* salt_ptr[4] = {salt, salt, salt, salt};
-  hash_update_x4(&ctx, salt_ptr, SALT_SIZE);
+  hash_update_x4_1(&ctx, salt, SALT_SIZE);
   hash_update_x4_uint16_le(&ctx, t);
   const uint16_t j_arr[4] = {j + 0, j + 1, j + 2, j + 3};
   hash_update_x4_uint16s_le(&ctx, j_arr);
@@ -151,13 +149,8 @@ static void commit_h_x4(uint8_t** digest, const commitments_t* C, const picnic_i
 
   hash_init_x4(&ctx, params->digest_size);
   for (size_t i = 0; i < params->num_MPC_parties; i++) {
-    const uint8_t* data[4] = {
-        C[0].hashes[i],
-        C[1].hashes[i],
-        C[2].hashes[i],
-        C[3].hashes[i],
-    };
-    hash_update_x4(&ctx, data, params->digest_size);
+    hash_update_x4_4(&ctx, C[0].hashes[i], C[1].hashes[i], C[2].hashes[i], C[3].hashes[i],
+                     params->digest_size);
   }
   hash_final_x4(&ctx);
   hash_squeeze_x4(&ctx, digest, params->digest_size);
@@ -187,13 +180,8 @@ static void commit_v_x4(uint8_t** digest, const uint8_t** input, const msgs_t* m
   hash_update_x4(&ctx, input, params->input_size);
   for (size_t i = 0; i < params->num_MPC_parties; i++) {
     assert(msgs[0].pos == msgs[1].pos && msgs[2].pos == msgs[3].pos && msgs[0].pos == msgs[2].pos);
-    const uint8_t* data[4] = {
-        msgs[0].msgs[i],
-        msgs[1].msgs[i],
-        msgs[2].msgs[i],
-        msgs[3].msgs[i],
-    };
-    hash_update_x4(&ctx, data, numBytes(msgs->pos));
+    hash_update_x4_4(&ctx, msgs[0].msgs[i], msgs[1].msgs[i], msgs[2].msgs[i], msgs[3].msgs[i],
+                     numBytes(msgs->pos));
   }
   hash_final_x4(&ctx);
   hash_squeeze_x4(&ctx, digest, params->digest_size);
@@ -520,7 +508,7 @@ static int verify_picnic3(signature2_t* sig, const uint8_t* pubKey, const uint8_
   }
 
   /* Compute the challenge; two lists of integers */
-  HCP(challenge, challengeC, challengeP, &Ch, treeCv->nodes[0], sig->salt, pubKey, plaintext,
+  HCP(challenge, challengeC, challengeP, &Ch, treeCv->nodes, sig->salt, pubKey, plaintext,
       message, messageByteLength, params);
 
   /* Compare to challenge from signature */
@@ -583,7 +571,7 @@ static int sign_picnic3(const uint8_t* privateKey, const uint8_t* pubKey, const
   memcpy(sig->salt, saltAndRoot, SALT_SIZE);
   tree_t* iSeedsTree =
       generateSeeds(params->num_rounds, saltAndRoot + SALT_SIZE, sig->salt, 0, params);
-  uint8_t** iSeeds = getLeaves(iSeedsTree);
+  uint8_t* iSeeds = getLeaves(iSeedsTree);
   free(saltAndRoot);
 
   randomTape_t* tapes = malloc(params->num_rounds * sizeof(randomTape_t));
@@ -606,7 +594,7 @@ static int sign_picnic3(const uint8_t* privateKey, const uint8_t* pubKey, const
   mzd_from_char_array(m_plaintext, plaintext, params->output_size);
 
   for (size_t t = 0; t < params->num_rounds; t++) {
-    seeds[t] = generateSeeds(params->num_MPC_parties, iSeeds[t], sig->salt, t, params);
+    seeds[t] = generateSeeds(params->num_MPC_parties, &iSeeds[t * params->seed_size], sig->salt, t, params);
     createRandomTapes(&tapes[t], getLeaves(seeds[t]), sig->salt, t, params);
     /* Preprocessing; compute aux tape for the N-th player, for each parallel rep */
     computeAuxTape(&tapes[t], inputs[t], params);
@@ -660,7 +648,7 @@ static int sign_picnic3(const uint8_t* privateKey, const uint8_t* pubKey, const
   /* Compute the challenge; two lists of integers */
   uint16_t* challengeC = sig->challengeC;
   uint16_t* challengeP = sig->challengeP;
-  HCP(sig->challenge, challengeC, challengeP, &Ch, treeCv->nodes[0], sig->salt, pubKey, plaintext,
+  HCP(sig->challenge, challengeC, challengeP, &Ch, treeCv->nodes, sig->salt, pubKey, plaintext,
       message, messageByteLength, params);
 
   /* Send information required for checking commitments with Merkle tree.
